# TE-SYSTEMS GmbH
# Script date: May 2024

# This script performs the following actions:
#	- Import the LOD license to anynode.

# In order to use the script, some variables must be adjusted.
#	- The path to the REST API PowerShell-Module must be set.
#		By default, the Powershell-Modul is in the folder directly above the one in which this script is located.
#	- The address of  anynode must be set.
#		By default the address is set to localhost.

#   --- LOD license import ---
#   - An email address must be specified for LOD activation.
#   - A company name must be specified for LOD activation.
#	- The LOD Key must be entered.

# Please check all existing parameters before starting the script.


# Set execution environment
Set-ExecutionPolicy -ExecutionPolicy Unrestricted -Scope Process

#---- Variables ----
# The path to the REST API PowerShell-Module must be specified. 
#	In this case. In this case it is in the folder above the one where this script is located.
Import-Module "./../anynode_rest_api_powershell.psm1"

# Define anynode's Address and Port.
$AnynodeAddress='127.0.0.1'
$AnynodePort=443

# Set the required details of the LOD.
$EmailAddress='EMAIL'
$CompanyName='COMPANY_NAME'
$LodKey='LOD_KEY'


# If you have not established a secure connection (HTTPS) to anynode,
# you can use HTTP instead.
# This is not recommended, since your data will NOT be encrypted!
# To activate it anyway, uncomment the following line:
# Disable-CertificateCheck

# Authentication
$Cred=Get-Credential

# ----------- Start of script -----------
try {
	# Request all network controllers and select the first one to select it as a licensing device
	$DeviceId=(Get-anynodeSystemIds -Address $AnynodeAddress -Port $AnynodePort -Credential $Cred | Select-Object -first 1).id
	
	# Importing the LOD license to anynode.
	Import-anynodeLOD -Address $AnynodeAddress -Port $AnynodePort -Credential $Cred -LODKey $LodKey -EmailAddress $EmailAddress -CompanyName $CompanyName -LicensingDevice $DeviceId
} catch {
	$_.Exception.Message
	pause
	return
}